@@ -1,20 +1,8 @@
-/*************************************************************************************
- *  Copyright 2014 Sebastian Kügler <sebas@kde.org>                                  *
- *                                                                                   *
- *  This library is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU Lesser General Public                       *
- *  License as published by the Free Software Foundation; either                     *
- *  version 2.1 of the License, or (at your option) any later version.               *
- *                                                                                   *
- *  This library is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
- *  Lesser General Public License for more details.                                  *
- *                                                                                   *
- *  You should have received a copy of the GNU Lesser General Public                 *
- *  License along with this library; if not, write to the Free Software              *
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
- *************************************************************************************/
+/*
+ *  SPDX-FileCopyrightText: 2014 Sebastian Kügler <sebas@kde.org>
+ *
+ *  SPDX-License-Identifier: LGPL-2.1-or-later
+ */
 
 #include "qscreenconfig.h"
 #include "qscreenbackend.h"
@@ -34,7 +22,7 @@ QScreenConfig::QScreenConfig(QObject *parent)
     , m_screen(new QScreenScreen(this))
     , m_blockSignals(true)
 {
-    foreach (const QScreen *qscreen, QGuiApplication::screens()) {
+    for (const QScreen *qscreen : QGuiApplication::screens()) {
         screenAdded(qscreen);
     }
     m_blockSignals = false;
@@ -58,7 +46,7 @@ ConfigPtr QScreenConfig::toKScreenConfig() const
 int QScreenConfig::outputId(const QScreen *qscreen)
 {
     QList<int> ids;
-    foreach (auto output, m_outputMap) {
+    for (auto output : qAsConst(m_outputMap)) {
         if (qscreen == output->qscreen()) {
             return output->id();
         }
@@ -84,7 +72,7 @@ void QScreenConfig::screenRemoved(QScreen *qscreen)
     qCDebug(KSCREEN_QSCREEN) << "Screen removed" << qscreen << QGuiApplication::screens().count();
     // Find output matching the QScreen object and remove it
     int removedOutputId = -1;
-    foreach (auto output, m_outputMap) {
+    for (auto output : m_outputMap) {
         if (output->qscreen() == qscreen) {
             removedOutputId = output->id();
             m_outputMap.remove(removedOutputId);
@@ -102,7 +90,7 @@ void QScreenConfig::updateKScreenConfig(ConfigPtr &config) const
 
     // Removing removed outputs
     KScreen::OutputList outputs = config->outputs();
-    Q_FOREACH (const KScreen::OutputPtr &output, outputs) {
+    for (const KScreen::OutputPtr &output : outputs) {
         if (!m_outputMap.contains(output->id())) {
             config->removeOutput(output->id());
         }
@@ -110,7 +98,7 @@ void QScreenConfig::updateKScreenConfig(ConfigPtr &config) const
 
     // Add KScreen::Outputs that aren't in the list yet, handle primaryOutput
     KScreen::OutputList kscreenOutputs = config->outputs();
-    foreach (QScreenOutput *output, m_outputMap) {
+    for (QScreenOutput *output : m_outputMap) {
         KScreen::OutputPtr kscreenOutput = kscreenOutputs[output->id()];
 
         if (!kscreenOutput) {
