@@ -1,20 +1,8 @@
 /*
- * Copyright (C) 2014  Daniel Vratil <dvratil@redhat.com>
- * Copyright 2015 Sebastian Kügler <sebas@kde.org>
+ * SPDX-FileCopyrightText: 2014 Daniel Vratil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2015 Sebastian Kügler <sebas@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  */
 
@@ -155,7 +143,8 @@ QFileInfo BackendManager::preferredBackend(const QString &backend)
         }
     }
     QFileInfo fallback;
-    Q_FOREACH (const QFileInfo &f, listBackends()) {
+    const auto backends = listBackends();
+    for (const QFileInfo &f : backends) {
         // Here's the part where we do the match case-insensitive
         if (f.baseName().toLower() == QStringLiteral("ksc_%1").arg(backendFilter.toLower())) {
             return f;
@@ -261,8 +250,8 @@ void BackendManager::requestBackend()
     const QByteArray args = qgetenv("KSCREEN_BACKEND_ARGS");
     QVariantMap arguments;
     if (!args.isEmpty()) {
-        QList<QByteArray> arglist = args.split(';');
-        Q_FOREACH (const QByteArray &arg, arglist) {
+        const QList<QByteArray> arglist = args.split(';');
+        for (const QByteArray &arg : arglist) {
             const int pos = arg.indexOf('=');
             if (pos == -1) {
                 continue;
